@@ -80,25 +80,14 @@ static inline size_t databuf_free_size(DataBuf *db)
 /****************************  Exported Functions  ***************************/
 /*****************************************************************************/
 
-void databuf_print(DataBuf *db, int print_data, char *fmt, ...);
-int databuf_init(DataBuf *db, size_t size, unsigned flags);
-void databuf_free(DataBuf *db);
-char *databuf_export(DataBuf *db);
-int databuf_append(DataBuf *db, const char *src, size_t src_size);
-int databuf_strcat(DataBuf *db, const char *str);
-int databuf_advance(DataBuf *db, size_t advance);
-int databuf_compress(DataBuf *db);
-int databuf_reset(DataBuf *db);
-
-/* Mark these private to prevent conflict with other libraries */
-hidden_proto(databuf_print);
-hidden_proto(databuf_init);
-hidden_proto(databuf_free);
-hidden_proto(databuf_export);
-hidden_proto(databuf_append);
-hidden_proto(databuf_strcat);
-hidden_proto(databuf_advance);
-hidden_proto(databuf_compress);
-hidden_proto(databuf_reset);
+void databuf_print(DataBuf *db, int print_data, char *fmt, ...) hidden;
+int databuf_init(DataBuf *db, size_t size, unsigned flags) hidden;
+void databuf_free(DataBuf *db) hidden;
+char *databuf_export(DataBuf *db) hidden;
+int databuf_append(DataBuf *db, const char *src, size_t src_size) hidden;
+int databuf_strcat(DataBuf *db, const char *str) hidden;
+int databuf_advance(DataBuf *db, size_t advance) hidden;
+int databuf_compress(DataBuf *db) hidden;
+int databuf_reset(DataBuf *db) hidden;
 
 #endif
