@@ -91,7 +91,8 @@ static char *escape(const char *tmp)
 		}
 		p++;
 	}
-	asprintf(&name, "\"%s\"", tmp);
+	if (asprintf(&name, "\"%s\"", tmp) < 0)
+		name = NULL;
 	return name;
 }
 
@@ -104,8 +105,10 @@ static int parse_up_record(rnode* r)
 
 	buf = strdup(r->record);
 	ptr = strtok_r(buf, " ", &saved);
-	if (ptr == NULL)
+	if (ptr == NULL) {
+		free(buf);
 		return -1;
+	}
 
 	do {	// If there's an '=' sign, its a keeper
 		nvnode n;
