@@ -67,7 +67,7 @@ _S(AUPARSE_TYPE_PERM,		"perm"		)
 _S(AUPARSE_TYPE_PERM,		"perm_mask"	)
 _S(AUPARSE_TYPE_MODE,		"mode"		)
 _S(AUPARSE_TYPE_SOCKADDR,	"saddr"		)
-_S(AUPARSE_TYPE_FLAGS,		"flags"		)
+//_S(AUPARSE_TYPE_FLAGS,		"flags"		)
 _S(AUPARSE_TYPE_PROMISC,	"prom"		)
 _S(AUPARSE_TYPE_PROMISC,	"old_prom"	)
 _S(AUPARSE_TYPE_CAPABILITY,	"capability"	)
@@ -78,6 +78,7 @@ _S(AUPARSE_TYPE_A1,		"a1"		)
 _S(AUPARSE_TYPE_A2,		"a2"		)
 _S(AUPARSE_TYPE_A3,		"a3"		)
 _S(AUPARSE_TYPE_SIGNAL,		"sig"		)
+_S(AUPARSE_TYPE_LIST,		"list"		)
 _S(AUPARSE_TYPE_TTY_DATA,	"data"		)
 _S(AUPARSE_TYPE_SESSION,	"ses"		)
 _S(AUPARSE_TYPE_CAP_BITMAP,	"cap_pi"	)
@@ -108,4 +109,11 @@ _S(AUPARSE_TYPE_ESCAPED,	"requested_mask")
 #endif
 _S(AUPARSE_TYPE_PERSONALITY,	"per"		)
 _S(AUPARSE_TYPE_SECCOMP,	"code"		)
+_S(AUPARSE_TYPE_ESCAPED,	"old-rng"	)
+_S(AUPARSE_TYPE_ESCAPED,	"new-rng"	)
+_S(AUPARSE_TYPE_OFLAG,		"oflag"		)
+_S(AUPARSE_TYPE_ESCAPED,	"ocomm"		)
+_S(AUPARSE_TYPE_MMAP,		"flags"		)
+_S(AUPARSE_TYPE_SIGNAL,		"sigev_signo"	)
+
 
