@@ -32,6 +32,7 @@ struct msg_tab {
     const char	*cvalue;
 };
 
+#ifndef NO_TABLES
 static const struct msg_tab err_msgtab[] = {
     { -1,    2,    "-F missing operation for" },
     { -2,    2,    "-F unknown field:" },
@@ -50,9 +51,15 @@ static const struct msg_tab err_msgtab[] = {
     { -15,    2,    "-F unknown errno -"},
     { -16,    2,    "-F unknown file type - " },
     { -17,    1,    "can only be used with exit and entry filter list" },
-    { -18,    1,    "can not be used with exclude filter list" },
+    { -18,    1,    "" }, // Unused
     { -19,    0,    "Key field needs a watch or syscall given prior to it" },
     { -20,    2,    "-F missing value after operation for" },
     { -21,    2,    "-F value should be number for" },
-    { -22,    2,    "-F missing field name before operator for" }
+    { -22,    2,    "-F missing field name before operator for" },
+    { -23,    2,    "" }, // Unused
+    { -24,    2,    "-C missing field name before operator for" },
+    { -25,    2,    "-C missing value after operation for "},
+    { -26,    2,    "-C unknown field:" },
+    { -27,    2,    "-C unknown right hand value for comparison with:" },
 };
+#endif
