@@ -23,4 +23,4 @@ _S(AUDIT_FILTER_TASK,    "task"     )
 _S(AUDIT_FILTER_ENTRY,   "entry"    )
 _S(AUDIT_FILTER_EXIT,    "exit"     )
 _S(AUDIT_FILTER_USER,    "user"     )
-_S(AUDIT_FILTER_WATCH,   "watch"    )
+_S(AUDIT_FILTER_EXCLUDE, "exclude"  )
