@@ -1,5 +1,5 @@
 /* lookup_table.c -- 
- * Copyright 2004-2008 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2004-2008,2012-13 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -34,30 +34,31 @@
 #include "gen_tables.h"
 #include "private.h"
 
+#ifndef NO_TABLES
 #ifdef WITH_ALPHA
 #include "alpha_tables.h"
 #endif
 #ifdef WITH_ARMEB
 #include "armeb_tables.h"
 #endif
+#ifdef WITH_AARCH64
+#include "aarch64_tables.h"
+#endif
 #include "i386_tables.h"
 #include "ia64_tables.h"
 #include "ppc_tables.h"
 #include "s390_tables.h"
 #include "s390x_tables.h"
 #include "x86_64_tables.h"
-#include "actiontabs.h"
 #include "errtabs.h"
-#include "fieldtabs.h"
-#include "flagtabs.h"
 #include "ftypetabs.h"
-#include "machinetabs.h"
-#include "msg_typetabs.h"
-#include "optabs.h"
-
-#ifndef EM_ARM
-#define EM_ARM  40
+#include "fieldtabs.h"
 #endif
+#include "msg_typetabs.h"
+#include "actiontabs.h"
+#include "flagtabs.h"
+#include "machinetabs.h"
+#include "optabs.h"
 
 struct int_transtab {
     int        key;
@@ -73,35 +74,45 @@ static const struct int_transtab elftab[] = {
     { MACH_S390X,   AUDIT_ARCH_S390X  },
     { MACH_S390,    AUDIT_ARCH_S390   },
 #ifdef WITH_ALPHA
-    { MACH_ALPHA,   AUDIT_ARCH_ALPHA  }
+    { MACH_ALPHA,   AUDIT_ARCH_ALPHA  },
 #endif
 #ifdef WITH_ARMEB
-    { MACH_ARMEB,   AUDIT_ARCH_ARMEB  }
+    { MACH_ARMEB,   AUDIT_ARCH_ARMEB  },
+#endif
+#ifdef WITH_AARCH64
+    { MACH_AARCH64, AUDIT_ARCH_AARCH64},
 #endif
 };
 #define AUDIT_ELF_NAMES (sizeof(elftab)/sizeof(elftab[0]))
 
 int audit_name_to_field(const char *field)
 {
+#ifndef NO_TABLES
 	int res;
 
 	if (field_s2i(field, &res) != 0)
 		return res;
+#endif
 	return -1;
 }
 hidden_def(audit_name_to_field)
 
 const char *audit_field_to_name(int field)
 {
+#ifndef NO_TABLES
 	return field_i2s(field);
+#else
+	return NULL;
+#endif
 }
 
 int audit_name_to_syscall(const char *sc, int machine)
 {
-	int res, found;
+	int res, found = 0;
 
 	switch (machine)
 	{
+#ifndef NO_TABLES
 		case MACH_X86:
 			found = i386_syscall_s2i(sc, &res);
 			break;
@@ -130,6 +141,12 @@ int audit_name_to_syscall(const char *sc, int machine)
 	        case MACH_ARMEB:
 			found = armeb_syscall_s2i(sc, &res);
 			break;
+#endif
+#ifdef WITH_AARCH64
+	        case MACH_AARCH64:
+			found = aarch64_syscall_s2i(sc, &res);
+			break;
+#endif
 #endif
 		default:
 			return -1;
@@ -142,6 +159,7 @@ hidden_def(audit_name_to_syscall)
 
 const char *audit_syscall_to_name(int sc, int machine)
 {
+#ifndef NO_TABLES
 	switch (machine)
 	{
 		case MACH_X86:
@@ -164,8 +182,13 @@ const char *audit_syscall_to_name(int sc, int machine)
 #ifdef WITH_ARMEB
 	        case MACH_ARMEB:
 			return armeb_syscall_i2s(sc);
+#endif
+#ifdef WITH_AARCH64
+	        case MACH_AARCH64:
+			return aarch64_syscall_i2s(sc);
 #endif
 	}
+#endif
 	return NULL;
 }
 
@@ -224,6 +247,7 @@ int audit_name_to_msg_type(const char *msg_type)
 		errno = 0;
 		return strtol(msg_type, NULL, 10);
 	}
+
 	return -1;
 }
 hidden_def(audit_name_to_msg_type)
@@ -279,6 +303,7 @@ hidden_def(audit_operator_to_symbol)
 /* This function returns 0 on error, otherwise the converted value */
 int audit_name_to_errno(const char *error)
 {
+#ifndef NO_TABLES
 	int rc, minus = 1;
 
 	if (*error == '-') {
@@ -289,30 +314,43 @@ int audit_name_to_errno(const char *error)
 		rc = 0;
 
 	return rc*minus;
+#else
+	return 0;
+#endif
 }
 hidden_def(audit_name_to_errno)
 
 /* This function does not handle negative numbers yet */
 const char *audit_errno_to_name(int error)
 {
+#ifndef NO_TABLES
 	if (error < 0)
 		return NULL;
 
         return err_i2s(error);
+#else
+	return NULL;
+#endif
 }
 
 int audit_name_to_ftype(const char *name)
 {
 	int res;
 
+#ifndef NO_TABLES
 	if (ftype_s2i(name, &res) != 0)
 		return res;
+#endif
 	return -1;
 }
 hidden_def(audit_name_to_ftype)
 
 const char *audit_ftype_to_name(int ftype)
 {
+#ifndef NO_TABLES
 	return ftype_i2s(ftype);
+#else
+	return NULL;
+#endif
 }
 
