@@ -1,5 +1,5 @@
 /* machine.h --
- * Copyright 2005,2006,2009,2012 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2005,2006,2009,2012,2013 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -40,3 +40,6 @@ _S(MACH_ARMEB,   "armv5tel")
 _S(MACH_ARMEB,   "armv6l")
 _S(MACH_ARMEB,   "armv7l")
 #endif
+#ifdef WITH_AARCH64
+_S(MACH_AARCH64,   "aarch64"  )
+#endif
