@@ -1,5 +1,5 @@
 /* s390x_table.h --
- * Copyright 2005-06,2008-12 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2005-06,2008-13 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -303,3 +303,6 @@ _S(338, "syncfs")
 _S(339, "setns")
 _S(340, "process_vm_readv")
 _S(341, "process_vm_writev")
+_S(342, "s390_runtime_instr")
+_S(343, "kcmp")
+_S(344, "finit_module")
