@@ -1,5 +1,5 @@
 /* auditd-config.c -- 
- * Copyright 2004-2011 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2004-2011,2013 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -669,8 +669,11 @@ static int dispatch_parser(struct nv_pair *nv, int line,
 		return 1;
 	}
 	if ((buf.st_mode & (S_IRWXU|S_IRWXG|S_IRWXO)) !=
-			   (S_IRWXU|S_IRGRP|S_IXGRP)) {
-		audit_msg(LOG_ERR, "%s permissions should be 0750", nv->value);
+			   (S_IRWXU|S_IRGRP|S_IXGRP) && 
+	    (buf.st_mode & (S_IRWXU|S_IRWXG|S_IRWXO)) !=
+			   (S_IRWXU|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH)) {
+		audit_msg(LOG_ERR, "%s permissions should be 0750 or 0755",
+				nv->value);
 		return 1;
 	}
 bypass:
@@ -920,8 +923,11 @@ static int check_exe_name(const char *val, int line)
 		return -1;
 	}
 	if ((buf.st_mode & (S_IRWXU|S_IRWXG|S_IRWXO)) !=
-			   (S_IRWXU|S_IRGRP|S_IXGRP)) {
-		audit_msg(LOG_ERR, "%s permissions should be 0750 - line %d",
+			   (S_IRWXU|S_IRGRP|S_IXGRP) &&
+	    (buf.st_mode & (S_IRWXU|S_IRWXG|S_IRWXO)) !=
+			   (S_IRWXU|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH)) {
+		audit_msg(LOG_ERR,
+			"%s permissions should be 0750 or 0755 - line %d",
 			val, line);
 		return -1;
 	}
@@ -955,25 +961,32 @@ static int space_action_parser(struct nv_pair *nv, int line,
 	return 1;
 }
 
-// returns 1 on error & 0 if OK
-int validate_email(const char *acct)
+// returns 0 if OK, 1 on temp error, 2 on permanent error
+static int validate_email(const char *acct)
 {
 	int i, len;
 	char *ptr1;
 
 	if (acct == NULL)
-		return 1;
+		return 2;
 
 	len = strlen(acct);
-	if (len < 2)
-		return 1;
+	if (len < 2) {
+		audit_msg(LOG_ERR,
+		    "email: %s is too short, expecting at least 2 characters",
+			 acct);
+		return 2;
+	}
 
 	// look for illegal char
 	for (i=0; i<len; i++) {
 		if (! (isalnum(acct[i]) || (acct[i] == '@') ||
 				(acct[i]=='.') || (acct[i]=='-') ||
-				(acct[i] == '_')) )
-			return 1;
+				(acct[i] == '_')) ) {
+			audit_msg(LOG_ERR, "email: %s has illegal character",
+				acct);
+			return 2;
+		}
 	}
 
 	if ((ptr1 = strchr(acct, '@'))) {
@@ -981,16 +994,26 @@ int validate_email(const char *acct)
 		struct hostent *t_addr;
 
 		ptr2 = strrchr(acct, '.');        // get last dot - sb after @
-		if ((ptr2 == NULL) || (ptr1 > ptr2))
-			return 1;
+		if ((ptr2 == NULL) || (ptr1 > ptr2)) {
+			audit_msg(LOG_ERR, "email: %s should have . after @",
+				acct);
+			return 2;
+		}
 
 		t_addr = gethostbyname(ptr1+1);
 		if (t_addr == 0) {
 			if ((h_errno == HOST_NOT_FOUND) ||
-					(h_errno == NO_RECOVERY))
-				return 1;
-			else if (h_errno == TRY_AGAIN)
+					(h_errno == NO_RECOVERY)) {
+					audit_msg(LOG_ERR,
+				"validate_email: failed looking up host for %s",
+					ptr1+1);
 				return 2;
+			}
+			else if (h_errno == TRY_AGAIN)
+				audit_msg(LOG_DEBUG,
+		"validate_email: temporary failure looking up domain for %s",
+					ptr1+1);
+				return 1;
 		}
 	}
 	return 0;
@@ -1007,7 +1030,7 @@ static int action_mail_acct_parser(struct nv_pair *nv, int line,
 	if (tmail == NULL)
 		return 1;
 
-	if (validate_email(tmail)) {
+	if (validate_email(tmail) > 1) {
 		free(tmail);
 		return 1;
 	}
@@ -1183,6 +1206,12 @@ static int tcp_listen_port_parser(struct nv_pair *nv, int line,
 	audit_msg(LOG_DEBUG, "tcp_listen_port_parser called with: %s",
 		  nv->value);
 
+#ifndef USE_LISTENER
+	audit_msg(LOG_DEBUG,
+		"Listener support is not enabled, ignoring value at line %d",
+		line);
+	return 0;
+#else
 	/* check that all chars are numbers */
 	for (i=0; ptr[i]; i++) {
 		if (!isdigit(ptr[i])) {
@@ -1217,6 +1246,7 @@ static int tcp_listen_port_parser(struct nv_pair *nv, int line,
 	}
 	config->tcp_listen_port = (unsigned int)i;
 	return 0;
+#endif
 }
 
 static int tcp_listen_queue_parser(struct nv_pair *nv, int line,
@@ -1228,6 +1258,12 @@ static int tcp_listen_queue_parser(struct nv_pair *nv, int line,
 	audit_msg(LOG_DEBUG, "tcp_listen_queue_parser called with: %s",
 		  nv->value);
 
+#ifndef USE_LISTENER
+	audit_msg(LOG_DEBUG,
+		"Listener support is not enabled, ignoring value at line %d",
+		line);
+	return 0;
+#else
 	/* check that all chars are numbers */
 	for (i=0; ptr[i]; i++) {
 		if (!isdigit(ptr[i])) {
@@ -1264,6 +1300,7 @@ static int tcp_listen_queue_parser(struct nv_pair *nv, int line,
 	}
 	config->tcp_listen_queue = (unsigned int)i;
 	return 0;
+#endif
 }
 
 
@@ -1276,6 +1313,12 @@ static int tcp_max_per_addr_parser(struct nv_pair *nv, int line,
 	audit_msg(LOG_DEBUG, "tcp_max_per_addr_parser called with: %s",
 		  nv->value);
 
+#ifndef USE_LISTENER
+	audit_msg(LOG_DEBUG,
+		"Listener support is not enabled, ignoring value at line %d",
+		line);
+	return 0;
+#else
 	/* check that all chars are numbers */
 	for (i=0; ptr[i]; i++) {
 		if (!isdigit(ptr[i])) {
@@ -1298,7 +1341,7 @@ static int tcp_max_per_addr_parser(struct nv_pair *nv, int line,
 	/* Check its range.  While this value is technically
 	   unlimited, it's limited by the kernel, and we limit it here
 	   for sanity. */
-	if (i > 16) {
+	if (i > 1024) {
 		audit_msg(LOG_ERR, 
 			"Error - converted number (%s) is too large - line %d",
 			nv->value, line);
@@ -1312,6 +1355,7 @@ static int tcp_max_per_addr_parser(struct nv_pair *nv, int line,
 	}
 	config->tcp_max_per_addr = (unsigned int)i;
 	return 0;
+#endif
 }
 
 static int use_libwrap_parser(struct nv_pair *nv, int line,
@@ -1342,6 +1386,12 @@ static int tcp_client_ports_parser(struct nv_pair *nv, int line,
 	audit_msg(LOG_DEBUG, "tcp_listen_queue_parser called with: %s",
 		  nv->value);
 
+#ifndef USE_LISTENER
+	audit_msg(LOG_DEBUG,
+		"Listener support is not enabled, ignoring value at line %d",
+		line);
+	return 0;
+#else
 	/* check that all chars are numbers, with an optional inclusive '-'. */
 	for (i=0; ptr[i]; i++) {
 		if (i > 0 && ptr[i] == '-' && ptr[i+1] != '\0') {
@@ -1406,6 +1456,7 @@ static int tcp_client_ports_parser(struct nv_pair *nv, int line,
 	config->tcp_client_min_port = (unsigned int)minv;
 	config->tcp_client_max_port = (unsigned int)maxv;
 	return 0;
+#endif
 }
 
 static int tcp_client_max_idle_parser(struct nv_pair *nv, int line,
@@ -1417,6 +1468,12 @@ static int tcp_client_max_idle_parser(struct nv_pair *nv, int line,
 	audit_msg(LOG_DEBUG, "tcp_client_max_idle_parser called with: %s",
 		  nv->value);
 
+#ifndef USE_LISTENER
+	audit_msg(LOG_DEBUG,
+		"Listener support is not enabled, ignoring value at line %d",
+		line);
+	return 0;
+#else
 	/* check that all chars are numbers */
 	for (i=0; ptr[i]; i++) {
 		if (!isdigit(ptr[i])) {
@@ -1447,6 +1504,7 @@ static int tcp_client_max_idle_parser(struct nv_pair *nv, int line,
 	}
 	config->tcp_client_max_idle = (unsigned int)i;
 	return 0;
+#endif
 }
 
 static int enable_krb5_parser(struct nv_pair *nv, int line,
