@@ -1,6 +1,6 @@
 /*
  * aureport.c - main file for aureport utility 
- * Copyright 2005-08, 2010,11 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2005-08, 2010,11,2013 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -46,7 +46,8 @@ event very_first_event, very_last_event;
 static FILE *log_fd = NULL;
 static lol lo;
 static int found = 0;
-static int process_logs(struct daemon_conf *config);
+static int files_to_process = 0; // Logs left when processing multiple
+static int process_logs(void);
 static int process_log_fd(const char *filename);
 static int process_stdin(void);
 static int process_file(char *filename);
@@ -68,7 +69,6 @@ static int is_pipe(int fd)
 
 int main(int argc, char *argv[])
 {
-	struct daemon_conf config;
 	struct rlimit limit;
 	int rc;
 
@@ -88,105 +88,94 @@ int main(int argc, char *argv[])
 	very_first_event.sec = 0;
 	reset_counters();
 
-	if (user_file == NULL) {
-		/* Load config so we know where logs are */
-        	if (load_config(&config, TEST_SEARCH))
-			fprintf(stderr, 
-				"NOTE - using built-in logs: %s\n",
-				config.log_file);
-	} else {
-		config.sender_ctx = NULL;
-		config.log_file = NULL;
-		config.dispatcher = NULL;
-		config.node_name = NULL;
-		config.space_left_exe = NULL;
-		config.action_mail_acct = NULL;
-		config.admin_space_left_exe = NULL;
-		config.disk_full_exe = NULL;
-		config.disk_error_exe = NULL;
-		config.krb5_principal = NULL;
-		config.krb5_key_file = NULL;
-	}
-		
 	print_title();
 	lol_create(&lo);
 	if (user_file)
 		rc = process_file(user_file);
 	else if (force_logs)
-		rc = process_logs(&config);
+		rc = process_logs();
 	else if (is_pipe(0))
 		rc = process_stdin();
 	else
-		rc = process_logs(&config);
+		rc = process_logs();
 	lol_clear(&lo);
-	if (rc) {
-		free_config(&config); 
+	if (rc)
 		return rc;
-	}
 
 	if (!found && report_detail == D_DETAILED && report_type != RPT_TIME) {
 		printf("<no events of interest were found>\n\n");
 		destroy_counters();
 		aulookup_destroy_uid_list();
 		aulookup_destroy_gid_list();
-		free_config(&config); 
 		return 1;
 	} else 
 		print_wrap_up();
 	destroy_counters();
 	aulookup_destroy_uid_list();
 	aulookup_destroy_gid_list();
-	free_config(&config); 
 	free(user_file);
 	return 0;
 }
 
-static int process_logs(struct daemon_conf *config)
+static int process_logs(void)
 {
+	struct daemon_conf config;
 	char *filename;
 	int len, num = 0;
 
+	/* Load config so we know where logs are */
+       	if (load_config(&config, TEST_SEARCH))
+		fprintf(stderr, "NOTE - using built-in logs: %s\n",
+			config.log_file);
 
 	/* for each file */
-	len = strlen(config->log_file) + 16;
+	len = strlen(config.log_file) + 16;
 	filename = malloc(len);
 	if (!filename) {
 		fprintf(stderr, "No memory\n");
+		free_config(&config);
 		return 1;
 	}
 	/* Find oldest log file */
-	snprintf(filename, len, "%s", config->log_file);
+	snprintf(filename, len, "%s", config.log_file);
 	do {
 		if (access(filename, R_OK) != 0)
 			break;
 // FIXME: do a time check and put them on linked list for later
 		num++;
-		snprintf(filename, len, "%s.%d", config->log_file, num);
+		snprintf(filename, len, "%s.%d", config.log_file, num);
 	} while (1);
 	num--;
+	/*
+	 * We note how many files we need to process
+	 */
+	files_to_process = num;
 
 	/* Got it, now process logs from last to first */
 	if (num > 0)
-		snprintf(filename, len, "%s.%d", config->log_file, num);
+		snprintf(filename, len, "%s.%d", config.log_file, num);
 	else
-		snprintf(filename, len, "%s", config->log_file);
+		snprintf(filename, len, "%s", config.log_file);
 	do {
 		int ret;
 		if ((ret = process_file(filename))) {
 			free(filename);
+			free_config(&config);
 			return ret;
 		}
 
 		/* Get next log file */
+		files_to_process--;     /* one less file to process */
 		num--;
 		if (num > 0)
-			snprintf(filename, len, "%s.%d", config->log_file, num);
+			snprintf(filename, len, "%s.%d", config.log_file, num);
 		else if (num == 0)
-			snprintf(filename, len, "%s", config->log_file);
+			snprintf(filename, len, "%s", config.log_file);
 		else
 			break;
 	} while (1);
 	free(filename);
+	free_config(&config);
 	return 0;
 }
 
@@ -298,7 +287,11 @@ static int get_record(llist **l)
 		} else {
 			free(buff);
 			if (feof_unlocked(log_fd)) {
-				terminate_all_events(&lo);
+				// Only mark all events complete if this is
+				// the last file.
+				if (files_to_process == 0) {
+					terminate_all_events(&lo);
+				}
 				*l = get_ready_event(&lo);
 				if (*l)
 					return 0;
