@@ -44,7 +44,8 @@ int main(int argc, char *argv[])
 	if (argc > 4) {
 		fputs("Too many arguments\n", stderr);
 		usage();
-	}
+	} else if (argc < 2)
+		usage();
  
 	for (i=1; i<argc; i++) {
 		if (isdigit(argv[i][0])) {
@@ -75,6 +76,12 @@ int main(int argc, char *argv[])
 			fputs("Arm eabi processor support is not enabled\n",
 					stderr);
 			exit(1);
+#endif
+#ifndef WITH_AARCH64
+		} else if (strcmp("aarch64", argv[i]) == 0) {
+			fputs("Aarch64 processor support is not enabled\n",
+					stderr);
+			exit(1);
 #endif
 		} else {
 			if (name != NULL) {
